@@ -1,4 +1,16 @@
 # (C) Copyright 2015-2016 Hewlett Packard Enterprise Development LP
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
+
 """ Metric data types
 """
 import logging
@@ -41,13 +53,6 @@ class Metric(object):
     def flush(self):
         if self.timestamp is None:
             return []
-        if self.value is None:
-            log.error('Value of None is not supported, will not send. '
-                      'Metric %s with dimensions %s at time %d',
-                      self.metric['name'],
-                      self.metric['dimensions'],
-                      self.timestamp)
-            return []
 
         envelope = self.measurement(self.value, self.timestamp)
         self.timestamp = None
@@ -114,7 +119,8 @@ class Rate(Metric):
     # redefine flush method to calculate rate from metrics
     def flush(self):
         # need at least two timestamps to determine rate
-        # is the second one is missing then the first is kept as start value for the subsequent interval
+        # is the second one is missing then the first is kept as start value for
+        # the subsequent interval
         if self.start_timestamp is None or self.timestamp is None:
             return []
 
@@ -123,8 +129,13 @@ class Rate(Metric):
         try:
             rate = delta_v / float(delta_t)
         except ZeroDivisionError:
-            log.warning('Conflicting values reported for metric %s with dimensions %s at time %d: (%f, %f)', self.metric['name'],
-                        self.metric['dimensions'], self.timestamp, self.start_value, self.value)
+            log.warning(
+                'Conflicting values reported for metric %s with dimensions %s at time %d: (%f, %f)',
+                self.metric['name'],
+                self.metric['dimensions'],
+                self.timestamp,
+                self.start_value,
+                self.value)
 
             # skip this measurement, but keep value for next cycle
             self.start_value = self.value
