@@ -1,5 +1,17 @@
 # (C) Copyright 2015-2016,2018 Hewlett Packard Enterprise Development LP
 # Copyright 2017 Fujitsu LIMITED
+#
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 
 import collections
 import copy
@@ -171,7 +183,9 @@ class MonascaAPI(object):
             log.info("Current measurements in queue: {0} of {1}".format(
                 self._current_number_measurements, self._max_measurement_buffer_size))
 
-            log.info("A message will be logged for every {0} messages queued.".format(MonascaAPI.LOG_INTERVAL))
+            log.info(
+                "A message will be logged for every {0} messages queued.".format(
+                    MonascaAPI.LOG_INTERVAL))
             self._log_interval_remaining = MonascaAPI.LOG_INTERVAL
         else:
             self._log_interval_remaining -= 1
